==> arm-compute-library_23.08+dfsg.orig.tar.xz: arm-compute-library-23.08+dfsg/src/common/IOperator.cpp <==
/*
 * Copyright (c) 2021 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include "src/common/IOperator.h"
#include "src/common/utils/Validate.h"

namespace arm_compute
{
#ifndef DOXYGEN_SKIP_THIS
IOperator::IOperator(IContext *ctx)
    : AclOperator_()
{
    ARM_COMPUTE_ASSERT_NOT_NULLPTR(ctx);
    this->header.ctx = ctx;
    this->header.ctx->inc_ref();
}

IOperator::~IOperator()
{
    this->header.ctx->dec_ref();
    this->header.type = detail::ObjectType::Invalid;
}

bool IOperator::is_valid() const
{
    return this->header.type == detail::ObjectType::Operator;
}

StatusCode IOperator::run(ITensorPack &tensors)
{
    _op->run(tensors);
    return StatusCode::Success;
}

StatusCode IOperator::run(IQueue &queue, ITensorPack &tensors)
{
    ARM_COMPUTE_UNUSED(queue);
    _op->run(tensors);
    return StatusCode::Success;
}

StatusCode IOperator::prepare(ITensorPack &tensors)
{
    _op->prepare(tensors);
    return StatusCode::Success;
}

MemoryRequirements IOperator::workspace() const
{
    return _op->workspace();
}
#endif /* DOXYGEN_SKIP_THIS */
} // namespace arm_compute

==> arm-compute-library_24.11+dfsg.orig.tar.xz: arm-compute-library-24.11+dfsg/src/common/IOperator.cpp <==
/*
 * Copyright (c) 2021 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include "src/common/IOperator.h"

#include "src/common/utils/Validate.h"

namespace arm_compute
{
#ifndef DOXYGEN_SKIP_THIS
IOperator::IOperator(IContext *ctx) : AclOperator_()
{
    ARM_COMPUTE_ASSERT_NOT_NULLPTR(ctx);
    this->header.ctx = ctx;
    this->header.ctx->inc_ref();
}

IOperator::~IOperator()
{
    this->header.ctx->dec_ref();
    this->header.type = detail::ObjectType::Invalid;
}

bool IOperator::is_valid() const
{
    return this->header.type == detail::ObjectType::Operator;
}

StatusCode IOperator::run(ITensorPack &tensors)
{
    _op->run(tensors);
    return StatusCode::Success;
}

StatusCode IOperator::run(IQueue &queue, ITensorPack &tensors)
{
    ARM_COMPUTE_UNUSED(queue);
    _op->run(tensors);
    return StatusCode::Success;
}

StatusCode IOperator::prepare(ITensorPack &tensors)
{
    _op->prepare(tensors);
    return StatusCode::Success;
}

MemoryRequirements IOperator::workspace() const
{
    return _op->workspace();
}
#endif /* DOXYGEN_SKIP_THIS */
} // namespace arm_compute
